@@ -18,6 +18,13 @@ class Agent(Traceback):
 		smartcard=False,
 	):
 
+		# docs.
+		DOCS = {
+			"module":"ssht00ls.agent", 
+			"initialized":True,
+			"description":[], 
+			"chapter": "Agent", }
+
 		# defaults.
 		Traceback.__init__(self, traceback="ssht00ls_agent", raw_traceback="ssht00ls.classes.agent.Agent")
 
@@ -149,7 +156,7 @@ class Agent(Traceback):
 				elif r == 1:
 					return dev0s.response.error("Provided an incorrect pin code.")
 				else:
-					raise ValueError(f"Unkown spawn behaviour: {spawn}")	
+					raise ValueError(f"Unknown spawn behaviour: {spawn}")	
 			except pexpect.exceptions.TIMEOUT:
 				a=1
 			except pexpect.exceptions.EOF:
