@@ -14,7 +14,14 @@ def __check_os__(supported=[]):
 class SmartCards(Traceback):
 	def __init__(self, 
 	):	
-		
+
+		# docs.
+		DOCS = {
+			"module":"ssht00ls.smartcards", 
+			"initialized":True,
+			"description":[], 
+			"chapter": "Keys", }
+
 		# defaults.
 		Traceback.__init__(self, traceback="ssht00ls.smartcards", raw_traceback="ssht00ls.classes.smartcards.SmartCards")
 
@@ -30,7 +37,7 @@ class SmartCards(Traceback):
 				if Files.exists(path):
 					self.path = path
 					break
-			if self.path == None: raise ValueError("Unable to locate opensc-pkcs11.so.")
+			if dev0s.defaults.options.log_level >= 1 and self.original_path == None: dev0s.response.log("Unable to locate opensc-pkcs11.so.", mode="warning")
 					
 		elif dev0s.defaults.vars.os in ["macos"]: 
 			self.original_path = None
@@ -226,6 +233,13 @@ class SmartCard(Traceback):
 	# another ssh : https://somm15.github.io/yubikey/macos/ssh/2018/11/20/welcome-to-jekyll.html
 	def __init__(self, serial_number=None):	
 
+		# docs.
+		DOCS = {
+			"module":"ssht00ls.SmartCard", 
+			"initialized":False,
+			"description":[], 
+			"chapter": "Keys", }
+
 		# defaults.
 		Traceback.__init__(self, traceback="ssht00ls.SmartCard", raw_traceback="ssht00ls.classes.smartcards.SmartCard")	
 
