@@ -12,6 +12,14 @@ class SSHD(Traceback):
 	def __init__(self,
 	):
 		
+
+		# docs.
+		DOCS = {
+			"module":"ssht00ls.sshd", 
+			"initialized":True,
+			"description":[], 
+			"chapter": "Setup", }
+
 		# defaults.
 		Traceback.__init__(self, traceback="ssht00ls.sshd", raw_traceback="ssht00ls.classes.sshd.SSHD")	
 
